@@ -2,11 +2,11 @@
 #'
 #' \if{html}{\figure{logo.jpeg}{options: width="120"}}
 #' 
-#' The \pkg{sumR} package provides some \code{R} functions that allow the
+#' The \pkg{sumR} package provides some `R` functions that allow the
 #' user to approximate the sum of series. It also interfaces the low level
-#' \code{C} functions that perform the actual summation, so that other packages
-#' can apply them to their own functions written in \code{C} or \code{C++}. The
-#' \href{https://github.com/GuidoAMoreira/sumR}{GitHub} page provides a short
+#' `C` functions that perform the actual summation, so that other packages
+#' can apply them to their own functions written in `C` or `C++`. The
+#' [GitHub](https://github.com/GuidoAMoreira/sumR) page provides a short
 #' tutorial on how to achieve this.
 #'
 #' The underlying code is under frequent revision for improvements in speed,
@@ -27,7 +27,8 @@
 #' @name sumR
 #'
 #' @useDynLib sumR, .registration = TRUE
-NULL
+#' @keywords internal
+"_PACKAGE"
 
 .onUnload <- function (libpath) {
   library.dynam.unload("sumR", libpath)
